@@ -2,9 +2,9 @@
 
 __author__ = 'Fabio Caccamo'
 __copyright__ = 'Copyright (c) 2019 Fabio Caccamo'
-__description__ = 'python-benedict is the Python dictionary for humans dealing with evil/complex data.'
+__description__ = 'The Python dictionary for humans dealing with evil/complex data.'
 __email__ = 'fabio.caccamo@gmail.com'
 __license__ = 'MIT'
 __title__ = 'benedict'
-__version__ = '0.3.0'
+__version__ = '0.4.1'
 
